Main contributors to the source code
------------------------------------
- Andrei Tsaregorodtsev <atsareg@in2p3.fr>
- Federico Stagni <federico.stagni@cern.ch>
- Zoltan Mathe <zoltan.mathe@cern.ch>
- Christophe Haen <christophe.denis.haen@cern.ch>
- Philippe Charpentier <philippe.charpentier@cern.ch>
- Andre Sailer <andre.philippe.sailer@cern.ch>
- Marko Petric <marko.petric@cern.ch>
- Simon Fayer <simon.fayer05@imperial.ac.uk>
- Andrew McNab <andrew.mcnab@cern.ch>
- Wojciech Krzemien <wojciech.krzemien@ncbj.gov.pl>

DIRAC consortium members
------------------------
- CNRS - Centre National de la Recherche Scientifique (France)
- CERN - European Organisation for Nuclear Research (Switzerland)
- IHEP (China)
- UM (Montpellier, France)
- PNNL (USA)
- KEK (Japan)
- Imperial College (UK)
